@@ -24,8 +24,10 @@ test_that("est_correlation = TRUE works", {
   skip_on_cran()
   set.seed(42)
   s <- sim_dfa(num_trends = 2, num_years = 20, num_ts = 3)
-  m <- fit_dfa(y = s$y_sim, iter = 50, chains = 1,
-               num_trends = 2, est_correlation = TRUE)
+  m <- fit_dfa(
+    y = s$y_sim, iter = 50, chains = 1,
+    num_trends = 2, est_correlation = TRUE
+  )
   expect_equal(class(m$model)[[1]], "stanfit")
 })
 
@@ -33,7 +35,7 @@ test_that("NA indexing works", {
   yy <- matrix(nrow = 3, ncol = 3, data = 1)
   yy[1, 1] <- NA
   yy[2, 3] <- NA
-  m <- fit_dfa(yy, num_trends = 1, sample = FALSE, scale="center")
+  m <- fit_dfa(yy, num_trends = 1, sample = FALSE, scale = "center")
   expect_equal(m$sampling_args$data$n_na, 2L)
   expect_equal(m$sampling_args$data$row_indx_na, c(1L, 2L))
   expect_equal(m$sampling_args$data$col_indx_na, c(1L, 3L))
@@ -55,7 +57,8 @@ test_that("find_dfa_trends works", {
       kmin = 1, kmax = 2, chains = 1, compare_normal = FALSE,
       variance = "equal", convergence_threshold = 1.1,
       control = list(adapt_delta = 0.95, max_treedepth = 20)
-    )})
+    )
+  })
 
   expect_equal(x$summary$model, c(2L, 1L))
   expect_lt(x$summary$looic[[1]], x$summary$looic[[2]])
@@ -66,12 +69,14 @@ test_that("long format data works", {
   set.seed(42)
   s <- sim_dfa(num_trends = 1, num_years = 20, num_ts = 3)
   m <- fit_dfa(y = s$y_sim, iter = 100, chains = 1, num_trends = 1, seed = 42)
-  wide_means = apply(extract(m$model, "x")$x[, 1, ], 2, mean)
+  wide_means <- apply(extract(m$model, "x")$x[, 1, ], 2, mean)
   # fit long format data
-  long = data.frame("obs" = c(s$y_sim[1,], s$y_sim[2,], s$y_sim[3,]),
-    "ts" = sort(rep(1:3,20)), "time" = rep(1:20,3))
-  m2 = fit_dfa(y = long, data_shape = "long", iter = 100, chains = 1, num_trends = 1, seed = 42)
-  long_means = apply(extract(m2$model, "x")$x[, 1, ], 2, mean)
+  long <- data.frame(
+    "obs" = c(s$y_sim[1, ], s$y_sim[2, ], s$y_sim[3, ]),
+    "ts" = sort(rep(1:3, 20)), "time" = rep(1:20, 3)
+  )
+  m2 <- fit_dfa(y = long, data_shape = "long", iter = 100, chains = 1, num_trends = 1, seed = 42)
+  long_means <- apply(extract(m2$model, "x")$x[, 1, ], 2, mean)
   expect_equal(cor(wide_means, long_means), 1, tolerance = 0.01)
 })
 
@@ -79,8 +84,10 @@ test_that("compositional model works", {
   skip_on_cran()
   set.seed(42)
   s <- sim_dfa(num_trends = 1, num_years = 20, num_ts = 3)
-  m <- fit_dfa(y = s$y_sim, iter = 50, chains = 1, num_trends = 2, seed = 42,
-    z_model = "proportion")
+  m <- fit_dfa(
+    y = s$y_sim, iter = 50, chains = 1, num_trends = 2, seed = 42,
+    z_model = "proportion"
+  )
 
   expect_equal(class(m$model)[[1]], "stanfit")
 })
@@ -89,8 +96,10 @@ test_that("compositional model works_2", {
   skip_on_cran()
   set.seed(42)
   s <- sim_dfa(num_trends = 2, num_years = 20, num_ts = 3)
-  m <- fit_dfa(y = s$y_sim, iter = 50, chains = 1, num_trends = 2, seed = 42,
-    z_model = "proportion")
+  m <- fit_dfa(
+    y = s$y_sim, iter = 50, chains = 1, num_trends = 2, seed = 42,
+    z_model = "proportion"
+  )
 
   expect_equal(class(m$model)[[1]], "stanfit")
 })
@@ -99,8 +108,10 @@ test_that("estimate_sigma_process_1", {
   skip_on_cran()
   set.seed(42)
   s <- sim_dfa(num_trends = 1, num_years = 20, num_ts = 3)
-  m <- fit_dfa(y = s$y_sim, iter = 50, chains = 1, num_trends = 2, seed = 42,
-    estimate_process_sigma = TRUE, equal_process_sigma = TRUE)
+  m <- fit_dfa(
+    y = s$y_sim, iter = 50, chains = 1, num_trends = 2, seed = 42,
+    estimate_process_sigma = TRUE, equal_process_sigma = TRUE
+  )
 
   expect_equal(class(m$model)[[1]], "stanfit")
 })
@@ -109,8 +120,10 @@ test_that("estimate_sigma_process_k", {
   skip_on_cran()
   set.seed(42)
   s <- sim_dfa(num_trends = 1, num_years = 20, num_ts = 3)
-  m <- fit_dfa(y = s$y_sim, iter = 50, chains = 1, num_trends = 2, seed = 42,
-    estimate_process_sigma = TRUE, equal_process_sigma = FALSE)
+  m <- fit_dfa(
+    y = s$y_sim, iter = 50, chains = 1, num_trends = 2, seed = 42,
+    estimate_process_sigma = TRUE, equal_process_sigma = FALSE
+  )
 
   expect_equal(class(m$model)[[1]], "stanfit")
 })
